==> nextcloud-app-contacts-3.4.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/zh_TW.js <==
OC.L10N.register(
    "contacts",
    {
    "All contacts" : "所有聯絡人",
    "Details" : "詳細資料",
    "Contacts" : "通訊錄",
    "A contacts app for Nextcloud" : "Nextcloud的通訊錄應用",
    "Add new property" : "新增屬性",
    "Choose property type" : "選擇屬性類型",
    "Upload a new picture" : "上傳一張新的圖片",
    "Choose from files" : "選擇檔案",
    "Download picture" : "下載圖片",
    "Delete picture" : "刪除圖片",
    "Invalid image" : "圖片無效",
    "Image is too big (max 1MB)." : "圖檔過大(最大1MB)",
    "No contact selected" : "未選擇聯絡人",
    "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
    "Name" : "名稱",
    "Company" : "公司",
    "Title" : "標題",
    "Download" : "下載",
    "Generate QR Code" : "產生QR Code",
    "Delete" : "刪除",
    "Cancel" : "取消",
    "Address book" : "通訊錄",
    "Groups" : "群組",
    "New contact" : "新聯絡人",
    "Syntax error. Cannot open the contact." : "語法錯誤。 無法打開聯絡人。",
    "Loading …" : "載入中...",
    "No results" : "沒有符合搜尋的項目",
    "Select type" : "選擇型態",
    "Select Date" : "選擇日期",
    "Add contact in group" : "新增聯絡人到群組",
    "Last modified" : "上一次修改",
    "Select option" : "選擇選項",
    "Rename" : "重新命名",
    "Enabled" : "已啟用",
    "Disabled" : "已停用",
    "Copied" : "已複製",
    "Can not copy" : "無法複製",
    "Copy link" : "複製連結",
    "Share with users or groups" : "與使用者或群組分享",
    "No users or groups" : "沒有使用者或群組",
    "can edit" : "允許編輯",
    "Import contacts" : "匯入連絡人",
    "Select local file" : "選擇本地檔案",
    "Import from files" : "匯入檔案",
    "Importing is disabled because there are no address books available" : "匯入被禁用，因為沒有可用的通訊錄",
    "Choose a vCard file to import" : "選擇vCard檔案匯入",
    "Address book name" : "通訊錄名稱",
    "First name" : "名",
    "Last name" : "姓",
    "Display name" : "顯示名稱",
    "Sort by {sorting}" : "排序依 {sorting}",
    "Create a new group" : "建立新群組",
    "Group name" : "群組名稱",
    "Loading contacts …" : "載入聯絡人…",
    "Create contact" : "建立聯絡人",
    "Not grouped" : "未歸類",
    "Recently contacted" : "最近聯絡",
    "Unable to create the contact." : "無法創建聯絡人",
    "Contact not found" : "找不到聯絡人",
    "Close" : "關閉",
    "Import" : "匯入",
    "Nickname" : "暱稱",
    "Detailed name" : "詳細名稱",
    "Additional names" : "別名/中間名",
    "Prefix" : "前綴",
    "Suffix" : "後綴",
    "Notes" : "筆記",
    "Website" : "網站",
    "Location" : "地點",
    "Federated Cloud ID" : "雲端聯邦 ID",
    "Home" : "住家",
    "Work" : "工作",
    "Other" : "其他",
    "Address" : "地址",
    "Post office box" : "郵政信箱",
    "City" : "城市",
    "State or province" : "州或省",
    "Postal code" : "郵遞區號",
    "Country" : "國家",
    "Birthday" : "生日",
    "Anniversary" : "週年",
    "Date of death" : "卒日",
    "Email" : "Email",
    "Instant messaging" : "即時通訊",
    "Phone" : "電話",
    "Mobile" : "行動電話",
    "Work mobile" : "工作行動電話",
    "Home mobile" : "家用電話",
    "Fax" : "傳真",
    "Fax home" : "傳真（家）",
    "Fax work" : "傳真（公司）",
    "Pager" : "呼叫器",
    "Voice" : "語音",
    "Car" : "車子",
    "Work pager" : "工作呼叫器",
    "Social network" : "社群網路",
    "Spouse" : "配偶",
    "Child" : "小孩",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姊妹",
    "Relative" : "親屬",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Manager" : "經理",
    "Assistant" : "助理",
    "Contact" : "聯絡人",
    "Agent" : "代理人",
    "Emergency" : "緊急",
    "Co-worker" : "同事",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "None" : "無",
    "Unknown" : "不明",
    "Timezone" : "時區",
    "Unable to delete contact" : "無法刪除聯絡人",
    "Your web browser is out of date" : "您的網路瀏覽器已過期",
    "This application is not compatible with Internet Explorer" : "這個應用程式和IE不相容"
},
"nplurals=1; plural=0;");

==> nextcloud-app-contacts-3.4.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/zh_TW.js <==
OC.L10N.register(
    "contacts",
    {
    "All contacts" : "所有聯絡人",
    "Details" : "詳細資料",
    "Contacts" : "通訊錄",
    "A contacts app for Nextcloud" : "Nextcloud的通訊錄應用",
    "Copy to full name" : "複製到全名",
    "Add new property" : "新增屬性",
    "Choose property type" : "選擇屬性類型",
    "Upload a new picture" : "上傳一張新的圖片",
    "Choose from Files" : "從檔案選取",
    "Get from " : "取得自",
    "Download picture" : "下載圖片",
    "Delete picture" : "刪除圖片",
    "Choose from files" : "選擇檔案",
    "Invalid image" : "圖片無效",
    "Image is too big (max 1MB)." : "圖檔過大(最大1MB)",
    "Pick an avatar" : "選擇一個頭像",
    "Error while processing the picture." : "處理相片時錯誤。",
    "Avatar downloaded from social network" : "從社群網路下載頭像",
    "Avatar already up to date" : "頭像已是最新",
    "Avatar download failed" : "頭像下載失敗",
    "No contact selected" : "未選擇聯絡人",
    "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
    "Name" : "名稱",
    "Company" : "公司",
    "Title" : "標題",
    "Download" : "下載",
    "Clone contact" : "複連絡人",
    "Generate QR Code" : "產生QR Code",
    "Delete" : "刪除",
    "Pick an address book" : "選取一個通訊錄",
    "Select address book" : "選擇通訊錄",
    "Cancel" : "取消",
    "Address book" : "通訊錄",
    "Groups" : "群組",
    "New contact" : "新聯絡人",
    "Syntax error. Cannot open the contact." : "語法錯誤。 無法打開聯絡人。",
    "Loading …" : "載入中...",
    "List is empty" : "清單是空的",
    "No results" : "沒有符合搜尋的項目",
    "Add to group" : "加入群組",
    "Add {type}" : "加入 {type}",
    "Select type" : "選擇型態",
    "Select Date" : "選擇日期",
    "Add contact in group" : "新增聯絡人到群組",
    "Last modified" : "上一次修改",
    "Select option" : "選擇選項",
    "Rename" : "重新命名",
    "Enabled" : "已啟用",
    "Disabled" : "已停用",
    "Copied" : "已複製",
    "Can not copy" : "無法複製",
    "Copy link" : "複製連結",
    "Delete {addressbook} ?" : "刪除 {addressbook}？",
    "Address book copied to clipboard" : "通訊錄已複製到剪貼簿。",
    "Address book was not copied to clipboard." : "通訊錄未複製到剪貼簿。",
    "Share with users or groups" : "與使用者或群組分享",
    "No users or groups" : "沒有使用者或群組",
    "can edit" : "允許編輯",
    "Unable to delete the share" : "無法刪除這個共享",
    "Unable to change permissions" : "無法變更權限",
    "Import contacts" : "匯入連絡人",
    "Select local file" : "選擇本地檔案",
    "Import from files" : "匯入檔案",
    "Importing is disabled because there are no address books available" : "匯入被禁用，因為沒有可用的通訊錄",
    "Choose a vCard file to import" : "選擇vCard檔案匯入",
    "Address book name" : "通訊錄名稱",
    "First name" : "名",
    "Last name" : "姓",
    "Display name" : "顯示名稱",
    "Sort by {sorting}" : "排序依 {sorting}",
    "Add contacts" : "新增連絡人",
    "+ New group" : "+ 新增群組",
    "Create a new group" : "建立新群組",
    "Group name" : "群組名稱",
    "Loading contacts …" : "載入聯絡人…",
    "There are no contacts yet" : "目前沒有連絡人",
    "Create contact" : "建立聯絡人",
    "There are no contacts in this group" : "群組中沒有連絡人",
    "Create contacts" : "建立連絡人",
    "Not grouped" : "未歸類",
    "Recently contacted" : "最近聯絡",
    "Unable to create the contact." : "無法創建聯絡人",
    "Contact not found" : "找不到聯絡人",
    "Group not found" : "找不到群組",
    "This group already exists" : "該群組已存在",
    "Close" : "關閉",
    "Import" : "匯入",
    "Nickname" : "暱稱",
    "Detailed name" : "詳細名稱",
    "Additional names" : "別名/中間名",
    "Prefix" : "前綴",
    "Suffix" : "後綴",
    "Notes" : "筆記",
    "Website" : "網站",
    "Location" : "地點",
    "Federated Cloud ID" : "雲端聯邦 ID",
    "Home" : "住家",
    "Work" : "工作",
    "Other" : "其他",
    "Address" : "地址",
    "Post office box" : "郵政信箱",
    "City" : "城市",
    "State or province" : "州或省",
    "Postal code" : "郵遞區號",
    "Country" : "國家",
    "Birthday" : "生日",
    "Anniversary" : "週年",
    "Date of death" : "卒日",
    "Email" : "Email",
    "Instant messaging" : "即時通訊",
    "Phone" : "電話",
    "Mobile" : "行動電話",
    "Work mobile" : "工作行動電話",
    "Home mobile" : "家用電話",
    "Fax" : "傳真",
    "Fax home" : "傳真（家）",
    "Fax work" : "傳真（公司）",
    "Pager" : "呼叫器",
    "Voice" : "語音",
    "Car" : "車子",
    "Work pager" : "工作呼叫器",
    "Social network" : "社群網路",
    "Spouse" : "配偶",
    "Child" : "小孩",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姊妹",
    "Relative" : "親屬",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Manager" : "經理",
    "Assistant" : "助理",
    "Contact" : "聯絡人",
    "Agent" : "代理人",
    "Emergency" : "緊急",
    "Co-worker" : "同事",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "None" : "無",
    "Unknown" : "不明",
    "Timezone" : "時區",
    "Unable to delete contact" : "無法刪除聯絡人",
    "Your web browser is out of date" : "您的網路瀏覽器已過期",
    "This application is not compatible with Internet Explorer" : "這個應用程式和IE不相容"
},
"nplurals=1; plural=0;");
